@@ -1,16 +1,16 @@
 package Dancer2::Plugin::SyntaxHighlight::Perl;
 
-our $VERSION = '0.0008';
+our $VERSION = '0.0009';
 
 use strict; use warnings;
 use Data::Dumper; $Data::Dumper::Indent = $Data::Dumper::Sortkeys = 1;
 use Dancer2::Plugin;
 use PPI::HTML;
 
-plugin_keywords qw/
+plugin_keywords(qw/
     highlight_perl
     highlight_output
-/;
+/);
 
 has line_numbers => (
     is      => 'lazy',
@@ -66,7 +66,7 @@ __END__
 
 =head1 VERSION
 
-version 0.0008
+version 0.0009
 
 =head1 NAME
 
